# django-osm-field

[![No Maintenance Intended](http://unmaintained.tech/badge.svg)](http://unmaintained.tech/)
![GitHub Workflow Status (branch)](https://img.shields.io/github/workflow/status/MarkusH/django-osm-field/CI/master?style=for-the-badge)
![Codecov branch](https://img.shields.io/codecov/c/gh/MarkusH/django-osm-field/master?style=for-the-badge)
![PyPI](https://img.shields.io/pypi/v/django-osm-field?style=for-the-badge)

An OpenStreetMap field for Django.

Documentation: https://django-osm-field.readthedocs.io/
